@@ -356,6 +356,53 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
         virtual void itemsUnlinked( const Akonadi::Item::List &items, const Akonadi::Collection &collection );
     };
 
+    /**
+     * Observer that adds support for item tagging
+     *
+     * @warning ObserverV4 subclasses ObserverV3 which changes behavior of some of the
+     * virtual methods from Observer and ObserverV2. Please make sure you read
+     * documentation of ObserverV3 and adapt your agent accordingly.
+     *
+     * @since 4.13
+     */
+    class AKONADI_EXPORT ObserverV4: public ObserverV3 // krazy:exclude=dpointer
+    {
+      public:
+        /**
+         * Reimplement to handle tags additions
+         *
+         * @param tag Newly added tag
+         */
+        virtual void tagAdded( const Akonadi::Tag &tag );
+
+        /**
+         * Reimplement to handle tags changes
+         *
+         * @param tag Tag that has been changed
+         */
+        virtual void tagChanged( const Akonadi::Tag &tag );
+
+        /**
+         * Reimplement to handle tags removal.
+         *
+         * @note All items that were tagged by @p tag will get a separate notification
+         * about untagging via itemsTagsChanged(). It is guaranteed that the itemsTagsChanged()
+         * notification will be delivered before this one.
+         *
+         * @param tag Tag that has been removed.
+         */
+        virtual void tagRemoved( const Akonadi::Tag &tag );
+
+        /**
+         * Reimplement to handle items tagging
+         *
+         * @param items Items that were tagged or untagged
+         * @param addedTags Set of tags that were added to all @p items
+         * @param removedTags Set of tags that were removed from all @p items
+         */
+        virtual void itemsTagsChanged( const Akonadi::Item::List &items, const QSet<Akonadi::Tag> &addedTags, const QSet<Akonadi::Tag> &removedTags );
+    };
+
     /**
      * This enum describes the different states the
      * agent can be in.
@@ -664,6 +711,31 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
      */
     void setOnline( bool state );
 
+    /**
+      * Sets the agent offline but will make it online again after a given time
+      *
+      * Use this method when the agent detects some problem with its backend but it wants
+      * to retry all pending operations after some time - e.g. a server can not be reached currently
+      *
+      * Example usage:
+      * @code
+      * void ExampleResource::onItemRemovedFinished(KJob *job)
+      * {
+      *     if (job->error()) {
+      *         emit status(Broken, job->errorString());
+      *         deferTask();
+      *         setTemporaryOffline(300);
+      *         return;
+      *     }
+      *     ...
+      * }
+      * @endcode
+      *
+      * @since 4.13
+      * @param makeOnlineInSeconds timeout in seconds after which the agent changes to online
+      */
+    void setTemporaryOffline(int makeOnlineInSeconds = 300);
+
   protected:
     //@cond PRIVATE
     AgentBasePrivate *d_ptr;
@@ -701,6 +773,7 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
     Q_PRIVATE_SLOT( d_func(), void slotError( const QString& ) )
     Q_PRIVATE_SLOT( d_func(), void slotNetworkStatusChange( Solid::Networking::Status ) )
     Q_PRIVATE_SLOT( d_func(), void slotResumedFromSuspend() )
+    Q_PRIVATE_SLOT(d_func(), void slotTemporaryOfflineTimeout())
 
     //@endcond
 };
