@@ -21,20 +21,34 @@
 #define AKOANDI_AGENTSEARCHINTERFACE_P_H
 
 #include "agentsearchinterface.h"
-
 #include <QObject>
 
+#include <akonadi/collection.h>
+
+
+class KJob;
+
 namespace Akonadi {
 
+class ImapSet;
+
 class AgentSearchInterfacePrivate : public QObject
 {
   Q_OBJECT
   public:
     explicit AgentSearchInterfacePrivate( AgentSearchInterface* qq );
 
+    void search( const QByteArray &searchId, const QString &query, quint64 collectionId );
     void addSearch( const QString &query, const QString &queryLanguage, quint64 resultCollectionId );
     void removeSearch( quint64 resultCollectionId );
 
+    QByteArray mSearchId;
+    qint64 mCollectionId;
+
+  private Q_SLOTS:
+    void delayedInit();
+    void collectionReceived( KJob *job );
+
   private:
     AgentSearchInterface* q;
 };
