@@ -23,12 +23,12 @@
 #include "etmcalendar.h"
 #include "calendarbase_p.h"
 #include "incidencechanger.h"
+#include "calendarmodel_p.h"
 
 #include <akonadi/entitytreemodel.h>
 #include <KCheckableProxyModel>
 
 #include <QSet>
-#include <QVector>
 #include <QModelIndex>
 
 class QAbstractItemModel;
@@ -125,7 +125,7 @@ public Q_SLOTS:
     void onCollectionPopulated(Akonadi::Collection::Id);
 
 public:
-    Akonadi::EntityTreeModel *mETM;
+    Akonadi::CalendarModel::Ptr mETM;
     Akonadi::EntityMimeTypeFilterModel *mFilteredETM;
 
     // akonadi id to collections
