@@ -508,6 +508,27 @@ void ETMCalendarTest::testItem()
 
 }
 
+void ETMCalendarTest::testShareETM()
+{
+    createTodo(QLatin1String("uid-123"), QString());
+    waitForIt();
+
+    ETMCalendar *calendar2 = new ETMCalendar(mCalendar, this);
+    calendar2->registerObserver(this);
+
+    // Uncheck our calendar
+    KCheckableProxyModel *checkable = calendar2->checkableProxyModel();
+    const QModelIndex firstIndex = checkable->index(0, 0);
+    QVERIFY(firstIndex.isValid());
+    mIncidencesToDelete = calendar2->incidences().count(); // number of incidence removed signals we get
+    checkable->setData(firstIndex, Qt::Unchecked, Qt::CheckStateRole);
+
+    // So, mCalendar has a calendar selection, while calendar2 has all it's calendars unchecked
+    // they are sharing the same ETM.
+    QVERIFY(!mCalendar->incidences().isEmpty());
+    QVERIFY(calendar2->incidences().isEmpty());
+}
+
 void ETMCalendarTest::waitForIt()
 {
     QTestEventLoop::instance().enterLoop(10);
