@@ -35,6 +35,7 @@
 #include <QHeaderView>
 #include <QLabel>
 #include <QVBoxLayout>
+#include <QCheckBox>
 
 #include <KLineEdit>
 #include <KLocalizedString>
@@ -70,6 +71,10 @@ class CollectionDialog::Private
       mView->header()->hide();
       layout->addWidget( mView );
 
+      mUseByDefault = new QCheckBox(i18n("Use folder by default"));
+      mUseByDefault->hide();
+      layout->addWidget(mUseByDefault);
+
       mParent->enableButton( KDialog::Ok, false );
 
       // setup models
@@ -113,10 +118,12 @@ class CollectionDialog::Private
       mSelectionHandler = new AsyncSelectionHandler( mFilterCollection, mParent );
       mParent->connect( mSelectionHandler, SIGNAL(collectionAvailable(QModelIndex)),
                         mParent, SLOT(slotCollectionAvailable(QModelIndex)) );
+      readConfig();
     }
 
     ~Private()
     {
+        writeConfig();
     }
 
     void slotCollectionAvailable( const QModelIndex &index )
@@ -131,6 +138,24 @@ class CollectionDialog::Private
          mView->expandAll();
     }
 
+    void readConfig()
+    {
+        KConfig config( QLatin1String( "akonadi_contactrc" ) );
+        KConfigGroup group( &config, QLatin1String( "CollectionDialog" ) );
+        const QSize size = group.readEntry( "Size", QSize(800,  500) );
+        if ( size.isValid() ) {
+            mParent->resize( size );
+        }
+    }
+
+    void writeConfig()
+    {
+        KConfig config( QLatin1String( "akonadi_contactrc" ) );
+        KConfigGroup group( &config, QLatin1String( "CollectionDialog" ) );
+        group.writeEntry( "Size", mParent->size() );
+        group.sync();
+    }
+
     CollectionDialog *mParent;
 
     ChangeRecorder *mMonitor;
@@ -142,6 +167,7 @@ class CollectionDialog::Private
     bool mAllowToCreateNewChildCollection;
     bool mKeepTreeExpanded;
     KRecursiveFilterProxyModel *mFilterCollection;
+    QCheckBox *mUseByDefault;
 
     void slotSelectionChanged();
     void slotAddChildCollection();
@@ -340,4 +366,15 @@ void CollectionDialog::changeCollectionDialogOptions( CollectionDialogOptions op
   d->changeCollectionDialogOptions( options );
 }
 
+void CollectionDialog::setUseFolderByDefault( bool b )
+{
+  d->mUseByDefault->setChecked(b);
+  d->mUseByDefault->show();
+}
+
+bool CollectionDialog::useFolderByDefault() const
+{
+  return d->mUseByDefault->isChecked();
+}
+
 #include "moc_collectiondialog.cpp"
