@@ -25,6 +25,8 @@
 #include "collectionutils_p.h"
 
 #include <klocale.h>
+#include <klocalizedstring.h>
+#include <kglobal.h>
 
 using namespace Akonadi;
 
