@@ -137,7 +137,7 @@ class AKONADI_EXPORT CollectionRequester : public KHBox
 
     Q_PRIVATE_SLOT( d, void _k_slotOpenDialog() )
     Q_PRIVATE_SLOT( d, void _k_collectionReceived( KJob *job ) )
-    Q_PRIVATE_SLOT( d, void _k_collectionsNamesReceived( KJob *job ) );
+    Q_PRIVATE_SLOT( d, void _k_collectionsNamesReceived( KJob *job ) )
 };
 
 } // namespace Akonadi
