@@ -45,14 +45,12 @@
 #include <ktabwidget.h>
 #include <ktextedit.h>
 
-#include <Nepomuk2/ResourceManager>
-
 #include <QtCore/QDirIterator>
 #include <QtCore/QPluginLoader>
 #include <QGroupBox>
 #include <QLabel>
-#include <QLayout>
 #include <QCheckBox>
+#include <QVBoxLayout>
 
 class ContactEditorWidget::Private
 {
@@ -257,14 +255,11 @@ void ContactEditorWidget::Private::initGuiContactTab()
   //phonesLayout->setRowStretch( 1, 1 );
 
   // setup categories section
-  const bool nepomukInitialized( Nepomuk2::ResourceManager::instance()->initialized() );
   QHBoxLayout *categoriesLayout = new QHBoxLayout;
   label = new QLabel( i18nc( "@label The categories of a contact", "Categories:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
-  label->setVisible( nepomukInitialized );
 
   mCategoriesWidget = new CategoriesEditWidget;
-  mCategoriesWidget->setVisible( nepomukInitialized );
   label->setBuddy( mCategoriesWidget );
 
   categoriesLayout->addWidget( label );
@@ -441,7 +436,7 @@ void ContactEditorWidget::Private::initGuiPersonalTab()
   label->setBuddy( mBirthdateWidget );
   datesLayout->addWidget( mBirthdateWidget, 0, 1 );
 
-  label = new QLabel( i18nc( "@label The anniversary of a contact", "Anniversary:" ) );
+  label = new QLabel( i18nc( "@label The wedding anniversary of a contact", "Anniversary:" ) );
   label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
   datesLayout->addWidget( label, 1, 0 );
 
