@@ -24,9 +24,10 @@
 #include <QApplication>
 #include <QDropEvent>
 #include <QMenu>
+#include <QDrag>
 
 #include <KDE/KIcon>
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 #include <KDE/KUrl>
 
 #include "akonadi/collection.h"
@@ -65,7 +66,8 @@ bool DragDropManager::dropAllowed( QDragMoveEvent *event ) const
     foreach ( const KUrl &url, urls ) {
       const Collection collection = Collection::fromUrl( url );
       if ( collection.isValid() ) {
-        if ( !supportedContentTypes.contains( Collection::mimeType() ) ) {
+        if ( !supportedContentTypes.contains( Collection::mimeType() ) &&
+             !supportedContentTypes.contains( Collection::virtualMimeType() ) ) {
           break;
         }
 
