@@ -26,8 +26,6 @@
 #include <QtCore/QMimeData>
 #include <QtCore/QTimer>
 #include <QAbstractProxyModel>
-#include <QApplication>
-#include <QPalette>
 
 #include <KDE/KIcon>
 #include <KDE/KLocalizedString>
@@ -784,6 +782,7 @@ bool EntityTreeModel::setData( const QModelIndex &index, const QVariant &value,
     } else if ( role == CollectionRefRole ) {
       d->ref( collection.id() );
     }
+    return true;
   }
 
   if ( index.column() == 0 &&
