@@ -742,12 +742,29 @@ void EntityTreeModelPrivate::insertCollection( const Akonadi::Collection& collec
   q->endInsertRows();
 }
 
-void EntityTreeModelPrivate::monitoredCollectionAdded( const Akonadi::Collection& collection, const Akonadi::Collection& parent )
+bool EntityTreeModelPrivate::shouldBePartOfModel( const Collection& collection ) const
 {
   if ( isHidden( collection ) ) {
-    return;
+    return false;
   }
 
+  // We want a parent collection if it has at least one child that matches the
+  // wanted mimetype
+  if ( m_childEntities.contains( collection.id() ) ) {
+    return true;
+  }
+
+  // Some collection trees contain multiple mimetypes. Even though server side filtering ensures we
+  // only get the ones we're interested in from the job, we have to filter on collections received through signals too.
+  if ( !m_mimeChecker.wantedMimeTypes().isEmpty() &&
+       !m_mimeChecker.isWantedCollection( collection ) ) {
+    return false;
+  }
+  return true;
+}
+
+void EntityTreeModelPrivate::monitoredCollectionAdded( const Akonadi::Collection& collection, const Akonadi::Collection& parent )
+{
   // If the resource is removed while populating the model with it, we might still
   // get some monitor signals. These stale/out-of-order signals can't be completely eliminated
   // in the akonadi server due to implementation details, so we also handle such signals in the model silently
@@ -761,15 +778,13 @@ void EntityTreeModelPrivate::monitoredCollectionAdded( const Akonadi::Collection
     return;
   }
 
+  //If the resource is explicitly monitored all other checks are skipped. topLevelCollectionsFetched still checks the hidden attribute.
   if ( m_monitor->resourcesMonitored().contains( collection.resource().toUtf8() ) &&
        collection.parentCollection() == Collection::root() ) {
     return topLevelCollectionsFetched( Collection::List() << collection );
   }
 
-  // Some collection trees contain multiple mimetypes. Even though server side filtering ensures we
-  // only get the ones we're interested in from the job, we have to filter on collections received through signals too.
-  if ( !m_mimeChecker.wantedMimeTypes().isEmpty() &&
-       !m_mimeChecker.isWantedCollection( collection ) ) {
+  if ( !shouldBePartOfModel( collection ) ) {
     return;
   }
 
@@ -787,10 +802,6 @@ void EntityTreeModelPrivate::monitoredCollectionAdded( const Akonadi::Collection
 
 void EntityTreeModelPrivate::monitoredCollectionRemoved( const Akonadi::Collection& collection )
 {
-  if ( isHidden( collection ) ) {
-    return;
-  }
-
   //if an explictly monitored collection is removed, we would also have to remove collections which were included to show it (as in the move case)
   if ( ( collection == m_rootCollection ) ||
        m_monitor->collectionsMonitored().contains( collection ) ) {
@@ -810,6 +821,7 @@ void EntityTreeModelPrivate::monitoredCollectionRemoved( const Akonadi::Collecti
   }
 
   // This may be a signal for a collection we've already removed by removing its ancestor.
+  // Or the collection may have been hidden.
   if ( !m_collections.contains( collection.id() ) ) {
     return;
   }
@@ -824,26 +836,11 @@ void EntityTreeModelPrivate::monitoredCollectionRemoved( const Akonadi::Collecti
 
   Q_ASSERT( m_collections.contains( parentId ) );
 
+  const Collection parentCollection = m_collections.value( parentId );
+
   m_populatedCols.remove( collection.id() );
 
-  const QModelIndex parentIndex = indexForCollection( m_collections.value( parentId ) );
-
-  // Top-level search collection
-  if ( parentId == 1 &&
-       m_childEntities.value( parentId ).size() == 1 &&
-       row == 0 ) {
-    // Special case for removing the last search folder.
-    // We need to remove the top-level search folder in that case.
-    const int searchCollectionRow = parentIndex.row();
-    q->beginRemoveRows( QModelIndex(), searchCollectionRow, searchCollectionRow );
-
-    removeChildEntities( parentId );
-    delete m_childEntities[ m_rootCollection.id() ].takeAt( searchCollectionRow );
-    m_collections.remove( parentId );
-
-    q->endRemoveRows();
-    return;
-  }
+  const QModelIndex parentIndex = indexForCollection( parentCollection );
 
   q->beginRemoveRows( parentIndex, row, row );
 
@@ -857,6 +854,11 @@ void EntityTreeModelPrivate::monitoredCollectionRemoved( const Akonadi::Collecti
   m_collections.remove( collection.id() );
 
   q->endRemoveRows();
+
+  // After removing a collection, check whether it's parent should be removed too
+  if ( !shouldBePartOfModel( parentCollection ) ) {
+    monitoredCollectionRemoved( parentCollection );
+  }
 }
 
 void EntityTreeModelPrivate::collectionSubscribed( const Akonadi::Collection& col, const Akonadi::Collection& parent )
@@ -977,15 +979,19 @@ void EntityTreeModelPrivate::monitoredCollectionMoved( const Akonadi::Collection
 
 void EntityTreeModelPrivate::monitoredCollectionChanged( const Akonadi::Collection &collection )
 {
-  if ( isHidden( collection ) ) {
-    return;
-  }
-
   if ( !m_collections.contains( collection.id() ) ) {
     // This can happen if
     // * we get a change notification after removing the collection.
     // * a collection of a non-monitored mimetype is changed elsewhere. Monitor does not
     //    filter by content mimetype of Collections so we get notifications for all of them.
+
+    //We might match the filter now, retry adding the collection
+    monitoredCollectionAdded( collection, collection.parentCollection() );
+    return;
+  }
+
+  if ( !shouldBePartOfModel( collection ) ) {
+    monitoredCollectionRemoved( collection );
     return;
   }
 
@@ -1056,7 +1062,7 @@ void EntityTreeModelPrivate::monitoredItemAdded( const Akonadi::Item& item, cons
     return;
   }
 
-  //Adding items to not yet populated columns would block fetchMore, resulting in only new items showing up in the collection
+  //Adding items to not yet populated collections would block fetchMore, resulting in only new items showing up in the collection
   //This is only a problem with lazy population, otherwise fetchMore is not used at all
   if ( (m_itemPopulation == EntityTreeModel::LazyPopulation) && !m_populatedCols.contains( collection.id() ) ) {
     return;
@@ -1130,7 +1136,10 @@ void EntityTreeModelPrivate::monitoredItemChanged( const Akonadi::Item &item, co
     return;
   }
 
-  m_items[ item.id() ].apply( item );
+  //otherwise this overwrites the copy of the real collection with one of the virtual collectoin
+  if (!item.parentCollection().isVirtual()) {
+    m_items[ item.id() ].apply( item );
+  }
 
   const QModelIndexList indexes = indexesForItem( item );
   foreach ( const QModelIndex &index, indexes ) {
@@ -1268,6 +1277,11 @@ void EntityTreeModelPrivate::monitoredItemUnlinked( const Akonadi::Item& item, c
   Q_ASSERT( m_collections.contains( collection.id() ) );
 
   const int row = indexOf<Node::Item>( m_childEntities.value( collection.id() ), item.id() );
+  if ( row < 0 || row >= m_childEntities[ collection.id() ].size() ) {
+    kWarning() << "couldn't find index of unlinked item " << item.id() << collection.id() << row;
+    Q_ASSERT(false);
+    return;
+  }
 
   const QModelIndex parentIndex = indexForCollection( m_collections.value( collection.id() ) );
 
@@ -1590,6 +1604,16 @@ bool EntityTreeModelPrivate::shouldPurge( Collection::Id id )
   return true;
 }
 
+bool EntityTreeModelPrivate::isMonitored( Collection::Id id )
+{
+  return m_monitor->d_ptr->isMonitored( id );
+}
+
+bool EntityTreeModelPrivate::isBuffered( Collection::Id id )
+{
+  return m_monitor->d_ptr->m_buffer.isBuffered( id );
+}
+
 void EntityTreeModelPrivate::deref( Collection::Id id )
 {
   const Collection::Id bumpedId = m_monitor->d_ptr->deref( id );
@@ -1598,6 +1622,11 @@ void EntityTreeModelPrivate::deref( Collection::Id id )
     return;
   }
 
+  //The collection has already been removed, don't purge
+  if ( !m_collections.contains( bumpedId ) ) {
+    return;
+  }
+
   if ( shouldPurge( bumpedId ) ) {
     purgeItems( bumpedId );
   }
@@ -1671,6 +1700,9 @@ void EntityTreeModelPrivate::purgeItems( Collection::Id id )
     end = childEntities.end();
   }
   m_populatedCols.remove(id);
+  //if an empty collection is purged and we leave it in here, itemAdded will be ignored for the collection
+  //and the collection is never populated by fetchMore (but maybe by statistics changed?)
+  m_collectionsWithoutItems.remove(id);
 }
 
 void EntityTreeModelPrivate::dataChanged( const QModelIndex &top, const QModelIndex &bottom )
