@@ -22,7 +22,6 @@
 
 #include <akonadi/item.h>
 #include <KJob>
-#include <QTime>
 
 #include <akonadi/collectionfetchjob.h>
 #include <akonadi/itemfetchscope.h>
@@ -233,6 +232,20 @@ public:
   void ref( Collection::Id id );
   void deref( Collection::Id id );
 
+  /**
+   * @returns true if the collection is actively monitored (referenced or buffered with refcounting enabled)
+   *
+   * purely for testing
+   */
+  bool isMonitored( Collection::Id id );
+
+  /**
+   * @returns true if the collection is buffered
+   *
+   * purely for testing
+   */
+  bool isBuffered( Collection::Id id );
+
   /**
     @returns true if the Collection with the id of @p id should be purged.
   */
@@ -288,6 +301,15 @@ public:
   Item itemForId( Item::Id id ) const;
 
   bool canFetchMore( const QModelIndex & parent ) const;
+
+  /**
+   * Returns true if the collection matches all filters and should be part of the model.
+   * This method checks all properties that could change by modifying the collection.
+   * Currently that includes:
+   * * hidden attribute
+   * * content mime types
+   */
+  bool shouldBePartOfModel( const Collection &collection ) const;
 };
 
 }
