@@ -26,8 +26,6 @@
 #include <KLocalizedString>
 
 #include <QtCore/QEvent>
-#include <QBoxLayout>
-#include <QLabel>
 #include <QPalette>
 
 using namespace Akonadi;
@@ -54,6 +52,7 @@ static bool isParentOf( QObject* o1, QObject* o2 )
 ErrorOverlay::ErrorOverlay( QWidget *baseWidget, QWidget * parent ) :
     QWidget( parent ? parent : baseWidget->window() ),
     mBaseWidget( baseWidget ),
+    mOverlayActive( false ),
     mBaseWidgetIsParent( false ),
     ui( new Ui::ErrorOverlay )
 {
@@ -234,8 +233,8 @@ void ErrorOverlay::serverStateChanged( ServerManager::State state )
         break;
       case ServerManager::Upgrading:
         ui->progressPage->setToolTip( i18n( "Personal information management service is performing a database upgrade." ) );
-        ui->progressDescription->setText( i18n( "Personal information management service is performing a database upgrade. "
-                                                "This happens after a software update and is necessary to optimize performance. "
+        ui->progressDescription->setText( i18n( "Personal information management service is performing a database upgrade.\n"
+                                                "This happens after a software update and is necessary to optimize performance.\n"
                                                 "Depending on the amount of personal information, this might take a few minutes.") );
         ui->stackWidget->setCurrentWidget( ui->progressPage );
         break;
