@@ -39,7 +39,8 @@ ItemModifyJobPrivate::ItemModifyJobPrivate( ItemModifyJob *parent )
   : JobPrivate( parent ),
     mRevCheck( true ),
     mIgnorePayload( false ),
-    mAutomaticConflictHandlingEnabled( true )
+    mAutomaticConflictHandlingEnabled( true ),
+    mSilent( false )
 {
 }
 
@@ -108,6 +109,11 @@ QString ItemModifyJobPrivate::jobDebuggingString() const
   }
 }
 
+void ItemModifyJobPrivate::setSilent( bool silent )
+{
+  mSilent = silent;
+}
+
 ItemModifyJob::ItemModifyJob( const Item &item, QObject * parent )
   : Job( new ItemModifyJobPrivate( this ), parent )
 {
@@ -178,6 +184,10 @@ QByteArray ItemModifyJobPrivate::fullCommand() const
   if ( item.d_func()->mClearPayload )
     changes << "INVALIDATECACHE";
 
+  if ( mSilent ) {
+    changes << "SILENT";
+  }
+
   if ( item.d_func()->mFlagsOverwritten ) {
     changes << "FLAGS";
     changes << '(' + ImapParser::join( item.flags(), " " ) + ')';
@@ -192,6 +202,20 @@ QByteArray ItemModifyJobPrivate::fullCommand() const
     }
   }
 
+  if ( item.d_func()->mTagsOverwritten ) {
+    changes << "TAGS";
+    changes << ' ' + ProtocolHelper::tagSetToImapSequenceSet( item.tags() );
+  } else {
+    if ( !item.d_func()->mAddedTags.isEmpty() ) {
+      changes << "+TAGS";
+      changes << ' ' + ProtocolHelper::tagSetToImapSequenceSet( item.d_func()->mAddedTags );
+    }
+    if ( !item.d_func()->mDeletedTags.isEmpty() ) {
+      changes << "-TAGS";
+      changes << ' ' + ProtocolHelper::tagSetToImapSequenceSet( item.d_func()->mDeletedTags );
+    }
+  }
+
   if ( !item.d_func()->mDeletedAttributes.isEmpty() ) {
     changes << "-PARTS";
     QList<QByteArray> attrs;
