@@ -33,8 +33,6 @@
 #include <QtCore/QEventLoop>
 #include <QtCore/QTimer>
 #include <QtCore/QTextStream>
-#include <QtNetwork/QHostAddress>
-#include <QtNetwork/QTcpSocket>
 #include <QtDBus/QDBusInterface>
 #include <QtDBus/QDBusConnectionInterface>
 
@@ -151,9 +149,15 @@ void JobPrivate::signalStartedToJobTracker()
   }
 }
 
+void JobPrivate::aboutToFinish()
+{
+  // Dummy
+}
+
 void JobPrivate::delayedEmitResult()
 {
   Q_Q( Job );
+  aboutToFinish();
   q->emitResult();
 }
 
