@@ -86,4 +86,37 @@ void setAllResourcesOffline() {
 #define AKVERIFYEXEC( job ) \
   QVERIFY2( job->exec(), job->errorString().toUtf8().constData() )
 
+// Taken from Qt 5:
+#if QT_VERSION < 0x050000
+
+// Will try to wait for the expression to become true while allowing event processing
+#define QTRY_VERIFY(__expr) \
+do { \
+  const int __step = 50; \
+  const int __timeout = 5000; \
+  if ( !( __expr ) ) { \
+    QTest::qWait( 0 ); \
+  } \
+  for ( int __i = 0; __i < __timeout && !( __expr ); __i += __step ) { \
+    QTest::qWait( __step ); \
+  } \
+  QVERIFY( __expr ); \
+} while ( 0 )
+
+// Will try to wait for the comparison to become successful while allowing event processing
+#define QTRY_COMPARE(__expr, __expected) \
+do { \
+  const int __step = 50; \
+  const int __timeout = 5000; \
+  if ( ( __expr ) != ( __expected ) ) { \
+    QTest::qWait( 0 ); \
+  } \
+  for ( int __i = 0; __i < __timeout && ( ( __expr ) != ( __expected ) ); __i += __step ) { \
+    QTest::qWait( __step ); \
+  } \
+  QCOMPARE( __expr, __expected ); \
+} while ( 0 )
+
+#endif
+
 #endif
