@@ -57,7 +57,7 @@ class AKONADI_TESTS_EXPORT SelfTestDialog : public KDialog
      */
     void hideIntroduction();
 
-  private slots:
+  private Q_SLOTS:
     void selectionChanged( const QModelIndex &index );
     void saveReport();
     void copyReport();
@@ -83,7 +83,6 @@ class AKONADI_TESTS_EXPORT SelfTestDialog : public KDialog
     void testPSQLServer();
     void testAkonadiCtl();
     void testServerStatus();
-    void testSearchStatus();
     void testProtocolVersion();
     void testResources();
     void testServerLog();
