@@ -25,7 +25,14 @@
 #include <qjson/serializer.h>
 #include <qjson/parser.h>
 
+class Akonadi::SocialNetworkAttributesPrivate
+{
+  public:
+    QVariantMap attributes;
+};
+
 Akonadi::SocialNetworkAttributes::SocialNetworkAttributes()
+  : d( new SocialNetworkAttributesPrivate() )
 {
 }
 
@@ -33,30 +40,32 @@ Akonadi::SocialNetworkAttributes::SocialNetworkAttributes( const QString &userNa
                                                            const QString &networkName,
                                                            bool canPublish,
                                                            uint maxPostLength )
+  : d( new SocialNetworkAttributesPrivate() )
 {
-  mAttributes[QLatin1String( "userName" )] = userName;
-  mAttributes[QLatin1String( "networkName" )] = networkName;
-  mAttributes[QLatin1String( "canPublish" )] = canPublish;
-  mAttributes[QLatin1String( "maxPostLength" )] = maxPostLength;
+  d->attributes[QLatin1String( "userName" )] = userName;
+  d->attributes[QLatin1String( "networkName" )] = networkName;
+  d->attributes[QLatin1String( "canPublish" )] = canPublish;
+  d->attributes[QLatin1String( "maxPostLength" )] = maxPostLength;
 }
 
 Akonadi::SocialNetworkAttributes::~SocialNetworkAttributes()
 {
+  delete d;
 }
 
 void Akonadi::SocialNetworkAttributes::deserialize( const QByteArray &data )
 {
   QJson::Parser parser;
-  mAttributes = parser.parse(data).toMap();
+  d->attributes = parser.parse(data).toMap();
 }
 
 QByteArray Akonadi::SocialNetworkAttributes::serialized() const
 {
   QJson::Serializer serializer;
 #if !defined( USE_QJSON_0_8 )
-  return serializer.serialize( mAttributes );
+  return serializer.serialize( d->attributes );
 #else
-  return serializer.serialize( mAttributes, 0 );
+  return serializer.serialize( d->attributes, 0 );
 #endif
 }
 
@@ -64,10 +73,10 @@ Akonadi::Attribute *Akonadi::SocialNetworkAttributes::clone() const
 {
   return
     new SocialNetworkAttributes(
-      mAttributes[QLatin1String( "userName" )].toString(),
-      mAttributes[QLatin1String( "networkName" )].toString(),
-      mAttributes[QLatin1String( "canPublish" )].toBool(),
-      mAttributes[QLatin1String( "maxPostLength" )].toUInt() );
+      d->attributes[QLatin1String( "userName" )].toString(),
+      d->attributes[QLatin1String( "networkName" )].toString(),
+      d->attributes[QLatin1String( "canPublish" )].toBool(),
+      d->attributes[QLatin1String( "maxPostLength" )].toUInt() );
 }
 
 QByteArray Akonadi::SocialNetworkAttributes::type() const
@@ -77,20 +86,20 @@ QByteArray Akonadi::SocialNetworkAttributes::type() const
 
 QString Akonadi::SocialNetworkAttributes::userName() const
 {
-  return mAttributes[QLatin1String( "userName" )].toString();
+  return d->attributes[QLatin1String( "userName" )].toString();
 }
 
 QString Akonadi::SocialNetworkAttributes::networkName() const
 {
-  return mAttributes[QLatin1String( "networkName" )].toString();
+  return d->attributes[QLatin1String( "networkName" )].toString();
 }
 
 bool Akonadi::SocialNetworkAttributes::canPublish() const
 {
-  return mAttributes[QLatin1String( "canPublish" )].toBool();
+  return d->attributes[QLatin1String( "canPublish" )].toBool();
 }
 
 uint Akonadi::SocialNetworkAttributes::maxPostLength() const
 {
-  return mAttributes[QLatin1String( "maxPostLength" )].toUInt();
+  return d->attributes[QLatin1String( "maxPostLength" )].toUInt();
 }
