@@ -341,7 +341,7 @@ class StandardActionManager::Private
       const Akonadi::Collection::List selectedCollectionsList = selectedCollections();
       const StandardActionManager::Type type = static_cast<StandardActionManager::Type>( menu->property( "actionType" ).toInt() );
 
-      QWeakPointer<RecentCollectionAction> recentCollection = new RecentCollectionAction( collectionSelectionModel->model(), menu );
+      QWeakPointer<RecentCollectionAction> recentCollection = new RecentCollectionAction( type, selectedCollectionsList,collectionSelectionModel->model(), menu );
       mRecentCollectionsMenu.insert( type, recentCollection );
       const QSet<QString> mimeTypes = mimeTypesOfSelection( type );
       fillFoldersMenu( selectedCollectionsList,
@@ -360,7 +360,7 @@ class StandardActionManager::Private
            type ==MoveCollectionToMenu )
       {
 
-        QWeakPointer<RecentCollectionAction> recentCollection = new RecentCollectionAction( collectionSelectionModel->model(), menu );
+        new RecentCollectionAction( type, Akonadi::Collection::List(), collectionSelectionModel->model(), menu );
         Collection::List selectedCollectionsList = selectedCollections();
         const QSet<QString> mimeTypes = mimeTypesOfSelection( type );
         fillFoldersMenu( selectedCollectionsList,
@@ -1189,7 +1189,7 @@ class StandardActionManager::Private
       while (item.hasNext()) {
         item.next();
         if ( item.value().data() ) {
-          item.value().data()->addRecentCollection( id );
+          item.value().data()->addRecentCollection( item.key(), id );
         }
       }
     }
@@ -1325,6 +1325,9 @@ class StandardActionManager::Private
 
         const bool readOnly = !isWritableTargetCollectionForMimeTypes( collection, mimeTypes, type );
         const bool collectionIsSelected = selectedCollectionsList.contains( collection );
+        if (type == MoveCollectionToMenu && collectionIsSelected) {
+          continue;
+        }
 
         QString label = model->data( index ).toString();
         label.replace( QLatin1String( "&" ), QLatin1String( "&&" ) );
@@ -1341,11 +1344,13 @@ class StandardActionManager::Private
 
           fillFoldersMenu( selectedCollectionsList, mimeTypes, type, popup, model, index );
 
-          if ( !readOnly ) {
-            popup->addSeparator();
+          if (!(type == CopyCollectionToMenu && collectionIsSelected)) {
+            if ( !readOnly ) {
+              popup->addSeparator();
 
-            QAction *action = popup->addAction( moveAction ? i18n( "Move to This Folder" ) : i18n( "Copy to This Folder" ) );
-            action->setData( QVariant::fromValue<QModelIndex>( index ) );
+              QAction *action = popup->addAction( moveAction ? i18n( "Move to This Folder" ) : i18n( "Copy to This Folder" ) );
+              action->setData( QVariant::fromValue<QModelIndex>( index ) );
+            }
           }
 
           menu->addMenu( popup );
