@@ -25,11 +25,16 @@
 #include "subscriptionmodel_p.h"
 
 #include <kdebug.h>
+#include <kglobal.h>
+#include <ksharedconfig.h>
 
-#include <QBoxLayout>
 
 #include <klocalizedstring.h>
 
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+
+
 #ifndef KDEPIM_MOBILE_UI
 #include <klineedit.h>
 #include <KPushButton>
@@ -38,7 +43,6 @@
 #include <QLabel>
 #include <QTreeView>
 #include <QCheckBox>
-#include <QItemSelectionModel>
 #else
 #include <kdescendantsproxymodel.h>
 #include <QListView>
@@ -97,6 +101,9 @@ class SubscriptionDialog::Private
     void slotSetPattern(const QString &text)
     {
       filterRecursiveCollectionFilter->setSearchPattern( text );
+#ifndef KDEPIM_MOBILE_UI
+      collectionView->expandAll();
+#endif
     }
     void slotSetIncludeCheckedOnly(bool checked)
     {
