@@ -227,7 +227,8 @@ class PluginRegistry
 {
   public:
     PluginRegistry()
-      : mDefaultPlugin( PluginEntry( QLatin1String( "application/octet-stream@QByteArray" ), s_defaultItemSerializerPlugin ) )
+      : mDefaultPlugin( PluginEntry( QLatin1String( "application/octet-stream@QByteArray" ), s_defaultItemSerializerPlugin ) ),
+        mOverridePlugin( 0 )
     {
       const PluginLoader* pl = PluginLoader::self();
       if ( !pl ) {
@@ -276,6 +277,9 @@ class PluginRegistry
     }
 
     QObject * findBestMatch( const QString & type, const QVector<int> & metaTypeIds ) {
+      if ( mOverridePlugin ) {
+        return mOverridePlugin;
+      }
       if ( QObject * const plugin = cacheLookup( type, metaTypeIds ) )
         // plugin cached, so let's take that one
         return plugin;
@@ -289,6 +293,10 @@ class PluginRegistry
       return plugin;
     }
 
+    void overrideDefaultPlugin( QObject *p ) {
+      mOverridePlugin = p;
+    }
+
 private:
     QObject * findBestMatchImpl( const QString &type, const QVector<int> & metaTypeIds, int & chosen ) const
     {
@@ -382,6 +390,7 @@ private:
 
   private:
     PluginEntry mDefaultPlugin;
+    QObject *mOverridePlugin;
 };
 
 K_GLOBAL_STATIC( PluginRegistry, s_pluginRegistry )
@@ -421,5 +430,8 @@ ItemSerializerPlugin* TypePluginLoader::defaultPluginForMimeType( const QString
   return plugin;
 }
 
+void TypePluginLoader::overridePluginLookup( QObject *p ) {
+    s_pluginRegistry->overrideDefaultPlugin( p );
+}
 
 }
