@@ -25,7 +25,7 @@
 #include <kacceleratormanager.h>
 #include <kcombobox.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <klineedit.h>
 #include <kmessagebox.h>
 #include <kpagewidget.h>
@@ -39,7 +39,6 @@
 #include <QSpinBox>
 #include <QRadioButton>
 
-
 using namespace KABC;
 
 ResourceLDAPKIOConfig::ResourceLDAPKIOConfig( QWidget *parent )
