@@ -35,6 +35,8 @@ class AddresseeTest : public QObject
     void assignmentTest();
     void serializeTest();
     void fullEmailTest();
+    void nameFromStringTest();
+    void customFieldsTest();
 };
 
 #endif
