@@ -19,7 +19,7 @@
 
 #include "deletejob.h"
 
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 #include <KDE/KDebug>
 
 #include "job_p.h"
@@ -67,4 +67,3 @@ QString DeleteJob::mailBox() const
   Q_D( const DeleteJob );
   return d->mailBox;
 }
-
