@@ -584,9 +584,16 @@ void LoginJob::connectionLost()
   //don't emit the result if the connection was lost before getting the tls result, as it can mean
   //the TLS handshake failed and the socket was reconnected in normal mode
   if ( d->authState != LoginJobPrivate::StartTls ) {
-    setError( ERR_COULD_NOT_CONNECT );
-    setErrorText( i18n( "Connection to server lost." ) );
-    emitResult();
+    kWarning() << "Connection to server lost " << d->m_socketError;
+    if ( d->m_socketError == KTcpSocket::SslHandshakeFailedError) {
+      setError( KJob::UserDefinedError );
+      setErrorText( i18n( "SSL handshake failed." ) );
+      emitResult();
+    } else {
+      setError( ERR_COULD_NOT_CONNECT );
+      setErrorText( i18n( "Connection to server lost." ) );
+      emitResult();
+    }
   }
 
 }
