@@ -25,7 +25,7 @@
 class ResponseParserTest : public QObject
 {
   Q_OBJECT
-  private slots:
+  private Q_SLOTS:
     void testResponseParser();
 };
 
