@@ -33,11 +33,9 @@
 #include <kio/global.h>
 #include <kio/sslui.h>
 #include <KLocalizedString>
-#include <kpimutils/networkaccesshelper.h>
 #include <KDebug>
 
 #include <QtCore/QQueue>
-#include <QtNetwork/QHostInfo>
 
 using namespace MailTransport;
 using namespace KioSMTP;
@@ -165,13 +163,13 @@ class MailTransport::SmtpSessionPrivate : public KioSMTP::SMTPSessionInterface
     bool sendCommandLine( const QByteArray &cmdline )
     {
       if ( cmdline.length() < 4096 ) {
-        kDebug(7112) << "C: >>" << cmdline.trimmed().data() << "<<";
+        kDebug( 7112 ) << "C: >>" << cmdline.trimmed().data() << "<<";
       } else {
-        kDebug(7112) << "C: <" << cmdline.length() << " bytes>";
+        kDebug( 7112 ) << "C: <" << cmdline.length() << " bytes>";
       }
       ssize_t numWritten, cmdline_len = cmdline.length();
       if ( ( numWritten = socket->write( cmdline ) ) != cmdline_len ) {
-        kDebug(7112) << "Tried to write " << cmdline_len << " bytes, but only "
+        kDebug( 7112 ) << "Tried to write " << cmdline_len << " bytes, but only "
                      << numWritten << " were written!" << endl;
         error( KIO::ERR_SLAVE_DEFINED, i18n ( "Writing to socket failed." ) );
         return false;
@@ -481,7 +479,7 @@ class MailTransport::SmtpSessionPrivate : public KioSMTP::SMTPSessionInterface
         // SMTP commands, for the benefit of the server.
         const QStringList recipients = request.recipients();
         for ( QStringList::const_iterator it = recipients.begin(); it != recipients.end(); ++it ) {
-          queueCommand( new RcptToCommand( this, (*it).toLatin1() ) );
+          queueCommand( new RcptToCommand( this, ( *it ).toLatin1() ) );
         }
 
         queueCommand( Command::DATA );
@@ -544,7 +542,7 @@ class MailTransport::SmtpSessionPrivate : public KioSMTP::SMTPSessionInterface
 bool SmtpSessionPrivate::saslInitialized = false;
 
 SmtpSession::SmtpSession( QObject *parent ) :
-  QObject(parent),
+  QObject( parent ),
   d( new SmtpSessionPrivate( this ) )
 {
   kDebug();
@@ -554,10 +552,6 @@ SmtpSession::SmtpSession( QObject *parent ) :
   connect( d->socket, SIGNAL(error(KTcpSocket::Error)), SLOT(socketError(KTcpSocket::Error)) );
   connect( d->socket, SIGNAL(readyRead()), SLOT(receivedNewData()), Qt::QueuedConnection );
 
-  // hold connection for the lifetime of this session
-  KPIMUtils::NetworkAccessHelper *networkHelper = new KPIMUtils::NetworkAccessHelper( this );
-  networkHelper->establishConnection();
-
   if ( !d->saslInitialized ) {
     if ( !initSASL() ) {
       exit( -1 );
@@ -620,7 +614,7 @@ void SmtpSession::sendMessage( const KUrl &destination, QIODevice *data )
     d->myHostname = d->request.heloHostname();
   } else {
     d->myHostname = QHostInfo::localHostName();
-    if( d->myHostname.isEmpty() ) {
+    if ( d->myHostname.isEmpty() ) {
       d->myHostname = QLatin1String( "localhost.invalid" );
     } else if ( !d->myHostname.contains( QLatin1Char( '.' ) ) ) {
       d->myHostname += QLatin1String( ".localnet" );
@@ -633,4 +627,4 @@ QString SmtpSession::errorMessage() const
   return d->errorMessage;
 }
 
-#include "smtpsession.moc"
+#include "moc_smtpsession.cpp"
