@@ -239,6 +239,12 @@ void SMTPConfigWidget::checkSmtpCapabilities()
   if ( d->ui.kcfg_specifyHostname->isChecked() ) {
     d->serverTest->setFakeHostname( d->ui.kcfg_localHostname->text() );
   }
+  QAbstractButton *encryptionChecked = d->encryptionGroup->checkedButton();
+  if (encryptionChecked == d->ui.none) {
+      d->serverTest->setPort( Transport::EnumEncryption::None, d->ui.kcfg_port->value());
+  } else if (encryptionChecked == d->ui.ssl) {
+      d->serverTest->setPort( Transport::EnumEncryption::SSL, d->ui.kcfg_port->value());
+  }
   d->serverTest->setProgressBar( d->ui.checkCapabilitiesProgress );
   d->ui.checkCapabilitiesStack->setCurrentIndex( 1 );
   BusyCursorHelper *busyCursorHelper = new BusyCursorHelper( d->serverTest );
@@ -294,6 +300,7 @@ void SMTPConfigWidget::slotFinished( QList<int> results )
   // connection failed and don't disable any of the radioboxes.
   if ( results.isEmpty() ) {
     d->serverTestFailed = true;
+    d->serverTest->deleteLater();
     return;
   }
 
@@ -311,6 +318,15 @@ void SMTPConfigWidget::slotFinished( QList<int> results )
   }
   d->sslCapa = d->serverTest->secureProtocols();
   d->updateAuthCapbilities();
+  //Show correct port from capabilities.
+  if (d->ui.ssl->isEnabled()) {
+      const int portValue = d->serverTest->port(Transport::EnumEncryption::SSL);
+      d->ui.kcfg_port->setValue(portValue == -1 ? SMTPS_PORT : portValue);
+  } else if (d->ui.none->isEnabled()) {
+      const int portValue = d->serverTest->port(Transport::EnumEncryption::None);
+      d->ui.kcfg_port->setValue(portValue == -1 ? SMTP_PORT : portValue);
+  }
+  d->serverTest->deleteLater();
 }
 
 void SMTPConfigWidget::hostNameChanged( const QString &text )
